@@ -4,7 +4,7 @@ from sys import argv
 
 from setux.targets import Local, SSH
 from setux.logger import debug
-from setux.repl import commands
+from setux.commands import commands
 from setux.repl.repl import repl, help
 from .usage import usage
 
@@ -37,6 +37,7 @@ def main():
         del argv[0]
         try: target = get_target(argv[-1])
         except: target = None
+
         if target:
             del argv[-1]
         else:
@@ -72,10 +73,13 @@ def main():
                 setattr(manager, attr, val)
             else:
                 command = getattr(manager, command)
-                gen = command(*args)
-                if gen:
-                    for vals in gen:
-                        print('\t'.join(vals))
+                if callable(command):
+                    gen = command(*args)
+                    if gen:
+                        for vals in gen:
+                            print('\t'.join(vals))
+                else:
+                    print(command)
             return
 
         if name=='help':
