@@ -62,4 +62,7 @@ helps = dict(
     ''',
     outlog = '''show commands log
     ''',
+    edit = '''edit remote file
+        arg = file path to edit
+    '''
 )
